/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */

editorIdToEditorMap = new Map();

function createEditorPane(parentElementId, contentType)
{
    var mode = contentType;
    {
        if (contentType == 'c')
            mode = 'c_cpp';
    }

    var editor = ace.edit(parentElementId);
    editor.setTheme("ace/theme/chrome");
    editor.getSession().setMode("ace/mode/" + mode);
    editor.$blockScrolling = Infinity; // disables a warning sent to the console as instructed by the warning itself
    editor.getSelection().on("changeCursor", function () { handleChangeCursorEvent(parentElementId, editor); })
    editor.on('change', function () { handleChangeEvent(parentElementId, editor); })
    editorIdToEditorMap.set(parentElementId, editor);

    return parentElementId;
}

function handleChangeCursorEvent(parentElementId, editor)
{
    var cursor = editor.selection.getCursor();

    var row = cursor.row + 1;
    var column = cursor.column + 1;
    handleCursorUpdated(parentElementId, row, column);
}

function handleChangeEvent(parentElementId, editor)
{
    var contents = editor.getValue();
    handleContentsUpdated(parentElementId, contents)
}

function setFileEditorContents(editorId, contents)
{
    var editor = editorIdToEditorMap.get(editorId);
    editor.setValue(contents);
    editor.gotoLine(-1); // move cursor to start of file
}

function setEditorPaneReadOnly(editorId)
{
    var editor = editorIdToEditorMap.get(editorId);
    editor.setReadOnly(true);
}

