/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of default_controllers;

class DefaultConsoleController extends ConsoleController
{
  final View _view;

  final ConsoleViewModel _vm;

  String _startupMessageString = null;

  HtmlElement _startupMessageHtml = null;

  factory DefaultConsoleController()
  {
    ConsoleViewModel vm = new ConsoleViewModel();
    return new DefaultConsoleController.modelAndView(vm, new DefaultConsoleView.defaultElementName(vm));
  }

  DefaultConsoleController.modelAndView(this._vm, this._view);

  @override
  void start()
  {
    super.start();

    _view.show();

    if(_startupMessageString != null)
    {
      _vm.appendTextLine(_startupMessageString);
    }
    else if(_startupMessageHtml != null)
    {
      _vm.appendHtml(_startupMessageHtml);
    }
  }

  void setStartupMessageString(String message)
  {
    _clearCurrentStartupMessage();
    _startupMessageString = message;
  }

  void setStartupMessageHtml(HtmlElement message)
  {
    _clearCurrentStartupMessage();
    _startupMessageHtml = message;
  }

  void _clearCurrentStartupMessage()
  {
    _startupMessageString = null;
    _startupMessageHtml = null;
  }

  @override
  void suspend() {
   _view.hide();
  }

  @override
  void resume() {
    _view.show();
  }

  @override
  void appendTextLine(String line) {
    _vm.appendTextLine(line);
  }

  @override
  void appendHtml(HtmlElement element) {
    _vm.appendHtml(element);
  }

  @override
  void clear() {
    _vm.clear();
  }
}