/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of default_controllers;

class LineFocusedEvent { final bool editor; final int lineNumber; LineFocusedEvent(this.editor, this.lineNumber); }


class DefaultDualSourceEditorController extends FileEditorController
{
  DefaultFileEditorController _editor1;

  DefaultFileEditorController _editor2;

  StreamController<LineFocusedEvent> _onLineFocusedController = new StreamController.broadcast();

  Stream<LineFocusedEvent> get onLineFocused => _onLineFocusedController.stream;

  var _makeEditorView;

  DefaultDualSourceEditorController(FileEditorView makeEditorView(FileEditorViewModel vm, String elementId))
  {
    _makeEditorView = makeEditorView;
  }

  void start([String source, FileType sourceLanguage])
  {
    startWithSources(source, sourceLanguage, source, sourceLanguage);
  }

  void startWithSources(String source1, FileType sourceLanguage1, String source2, FileType sourceLanguage2,
  [bool source1ReadOnly = false, bool source2ReadOnly = false])
  {

    var convertToContent = (FileType fileType)
    {
      return fileType(
              (java) => ContentModeJava,
              (c) => ContentModeC,
              (js) => ContentModeJavaScript);
    };

    FileEditorViewModel source1Vm = new FileEditorViewModel(source1, convertToContent(sourceLanguage1), source1ReadOnly);

    FileEditorViewModel source2Vm = new FileEditorViewModel(source2, convertToContent(sourceLanguage2), source2ReadOnly);



    _editor1 = _makeSubController(source1Vm, "editor2")
      ..start();
    _editor2 = _makeSubController(source2Vm, "editor3")
      ..start();


    showEastPane();

    super.start();

  }

  DefaultFileEditorController _makeSubController(FileEditorViewModel vm, String parentId)
  {
    FileEditorView view = _makeEditorView(vm, querySelector("#" + parentId));
    DefaultFileEditorController controller = new DefaultFileEditorController(vm, view);


    view.onFocusedLineChanged.listen((int lineNumber) { _handleOnLineFocused(controller, lineNumber); });


    return controller;
  }

  _handleOnLineFocused(DefaultFileEditorController controller, int lineNumber)
  {
    if(_editor1 == null || _editor2 == null)
      return;


    if(identical(controller, _editor1))
      _onLineFocusedController.add(new LineFocusedEvent(true, lineNumber));
    else if(identical(controller, _editor2))
      _onLineFocusedController.add(new LineFocusedEvent(false, lineNumber));
    else
      throw "logical exception";
  }

  /*
  void highlightBothLines(int lineNumber)
  {
    this.assertHasStarted();

    _editor1.highlightLine(lineNumber);
    _editor2.highlightLine(lineNumber);

  }

  void highlightSource2Line(int lineNumber)
  {
    this.assertHasStarted();

    _editor2.highlightLine(lineNumber);
  } */

  /*
  void stripeSource1Line(int lineNumber)
  {
    this.assertHasStarted();

    _editor1.stripeLine(lineNumber);
  } */

  @override
  void suspend()
  {
    this.assertHasStarted();

    hideEastPane();
    _editor1.suspend();
    _editor2.suspend();
  }


  @override
  void resume() {
    this.assertHasStarted();

    showEastPane();
    _editor1.resume();
    _editor2.resume();
  }

  @override
  void set contents(String contents) {
    this.assertHasStarted();
    _editor1.contents = contents;
    _editor2.contents = contents;
  }

  @override
  void set fileType(FileType sourceLanguage)
  {
    this.assertHasStarted();
    _editor1.fileType = sourceLanguage;
    _editor2.fileType = sourceLanguage;
  }

  // TODO: implement onSourceChanged
  @override
  Stream<String> get onContentsChanged => null;

}

@JS()
external showEastPane();

@JS()
external hideEastPane();