/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of default_controllers;

/**
 * A de
 */
class DefaultFileEditorController extends FileEditorController<String>
{
  FileEditorViewModel _sourceEditorVm;

  FileEditorView _sourceEditorView;

  Stream<String> get onContentsChanged => _sourceEditorView.onContentsChanged;

  DefaultFileEditorController(this._sourceEditorVm, this._sourceEditorView)
  {
    if(this._sourceEditorView == null)
      throw new ArgumentError.notNull("_sourceEditorView");

   _sourceEditorView.onContentsChanged.listen(_handleSourceChanged);
  }

  void _handleSourceChanged(String newSource)
  {
    _sourceEditorVm.setContents(newSource, false);
  }

  @override
  void start()
  {
    super.start();
    _sourceEditorView.show();
  }

  void suspend()
  {
    _sourceEditorView.hide();
  }

  @override
  void resume() {
    _sourceEditorView.show();
  }


  void set contents(String contents)
  {

    _sourceEditorVm.setContents(contents);
  }

  void set fileType(FileType sourceLanguage)
  {
    ContentMode editorMode = sourceLanguage(
        (java) => ContentModeJava,
        (c) => ContentModeC,
        (js) => ContentModeJavaScript);
    _sourceEditorVm.setContentMode(editorMode);
  }

}