/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of default_controllers;

/**
 * A default controller for creating a toolbar presenting the user a "New File" button.
 *
 * Assumes an HTML element exists to represent the "New File" button.
 *
 */
class DefaultToolbarController extends ToolbarController
{
  @override
  Stream get onNewFileCreationRequested => _onNewFileRequestedController.stream;

  /**
   * Backing controller for [onNewFileCreationRequested]
   */
  final StreamController _onNewFileRequestedController = new StreamController.broadcast();

  /**
   * The id of the HTML element used as the "New File" button.
   */
  final String _newFileButtonId;

  /**
   * Creates a new toolbar controller optionally specifying the id of the HTML element used as the
   * "New File" button.
   *
   * If no value is provided for [newFileButtonId], the id is assumed to be "new-file-button"
   */
  factory DefaultToolbarController([String newFileButtonId])
  {
    newFileButtonId = newFileButtonId == null ? "new-file-button" : newFileButtonId;

    return new DefaultToolbarController.allParams(newFileButtonId);
  }

  /**
   * Creates a new toolbar controller using the given id for the HTML element id of the "New File" button.
   */
  DefaultToolbarController.allParams(this._newFileButtonId);

  @override
  void start()
  {
    super.start();

    ButtonElement newFileButton = querySelector('#' + _newFileButtonId);

    newFileButton.onClick.listen((MouseEvent e) { _handleNewFileButtonClicked(); });
  }

  /**
   * React to "New File" being clicked by firing an event on [onNewFileCreationRequested].
   */
  void _handleNewFileButtonClicked()
  {
    _onNewFileRequestedController.add(null);
  }


  @override
  void suspend() {
    // TODO: implement hide
  }

  @override
  void resume() {
    // TODO: implement show
  }
}