/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of default_views;

/**
 * A basic console view that appends all HTML message to a DOM element.
 */
class DefaultConsoleView extends ElementView
{
  /**
   * The view model of the console.
   */
  final ConsoleViewModel _vm;

  /**
   * The DOM element used to render console messages.
   */
  Element _consoleElement;

  /**
   * Flag to indicate if [show()] has ever been called.
   */
  bool _everShown = false;

  /**
   * Constructs a view the appends all messages to an element assumed to have id "console".
   */
  DefaultConsoleView.defaultElementName(ConsoleViewModel vm)
      : this(vm, querySelector('#console'));

  /**
   * Constructs a view the appends all messages to the given [consoleElement].
   */
  DefaultConsoleView(this._vm, Element consoleElement) : super(consoleElement)
  {
    if(consoleElement == null)
      new ArgumentError("consoleElement may not be null.");

    _consoleElement = consoleElement;
  }

  @override
  void show()
  {
    if(!_everShown)
    {
      _vm.onHtmlAppended.listen(_handleHtmlAppended);
      _vm.onCleared.listen((_) { _handleCleared(); });
      _everShown = true;
    }

    super.show();
  }

  /**
   * Appends the given HTML to [_consoleElement] as a child element.
   */
  void _handleHtmlAppended(HtmlElement message)
  {
    _consoleElement.children.add(message);
  }

  /**
   * Clears all the children of [_consoleElement].
   */
  void _handleCleared()
  {
    _consoleElement.children.clear();
  }
}