/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of view_models;

/**
 * Model of a message console for displaying HTML messages to the user.
 */
class ConsoleViewModel
{

  /**
   * Fired when new messages are appended to the console. See [appendHtml(...)] or [appendTextLine(...)].
   */
  Stream<HtmlElement> get onHtmlAppended => _onHtmlAppendedController.stream;

  /**
   * Backing controller for [onHtmlAppended].
   */
  StreamController<HtmlElement> _onHtmlAppendedController = new StreamController.broadcast();

  /**
   * Fired when messages are removed from the console. See [clear()].
   */
  Stream<String> get onCleared => _onClearedController.stream;

  /**
   * Backing controller for [onCleared].
   */
  StreamController _onClearedController = new StreamController.broadcast();


  /**
   * Wraps the given string in HTML pre tags and appends the HTML to the console.
   */
  void appendTextLine(String line)
  {
    PreElement lineElement = new PreElement()..setInnerHtml(line);
    appendHtml(lineElement);
  }

  /**
   * Appends the given HtML to the console.
   */
  void appendHtml(HtmlElement element)
  {
    _onHtmlAppendedController.add(element);
  }

  /**
   * Removes all messges from the console.
   */
  void clear()
  {
    _onClearedController.add(null);
  }
}