/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of view_models;

/**
 * A model for a hierarchical collection of file paths to be displayed to the user. Each path is represented in this
 * model as a [ParsedPath].
 *
 * Duplicate file entries are allowed and will be preserved in the explorer.
 */
class ProjectExplorerViewModel
{

  /**
   * Fired when a new files are added to the explorer.  Message content is the collection of files given to the
   * explorer.
   *
   * The files contained in the message content are exactly those given to the explorer via [addFile] or [addFiles].
   * The message may contain files that preexisted in the explorer prior to invocation of these methods.
   */
  Stream get onFilesAdded => _onFilesAddedController.stream;

  /**
   * Backing controller for [onFilesAdded]
   */
  StreamController<Iterable<ParsedPath>> _onFilesAddedController = new StreamController.broadcast();

  /**
   * The files contained in the explorer.
   */
  List<ParsedPath> _files = [];

  /**
   * The files contained in the explorer.
   */
  Iterable<ParsedPath> get files => _files;

  /**
   * Adds the given file to the explorer.
   */
  void addFile(ParsedPath file)
  {
    addFiles([file]);
  }

  /**
   * Adds the given files to the explorer.
   */
  void addFiles(Iterable<ParsedPath> files)
  {
    _files.addAll(files);
    _onFilesAddedController.add(files);
  }
}