/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of vellum.views;

/**
 * A [FileEditorView] that is implemented outside of this framework/Dart (most likely in JavaScript).
 *
 * Serves as a proxy instance for the actual file editor view in the foreign framework.
 */
abstract class FileEditorViewExternal implements FileEditorView
{
  /**
   * A unique identifier for the editor instance and its corresponding foreign framework member.
   */
  Object get id;


  /**
   * Informs the proxy instance that the cursor row and column may have changed as a result
   * of operations carried out in the foreign framework.
   */
  void handleCursorUpdatedExternally(int cursorRow, int cursorColumn);

  /**
   * Informs the proxy instance that the file contents may have changed as a result of operations carried out in the
   * foreign framework.
   */
  void handleContentsUpdatedExternally(String newContents);

}