/**
 * Copyright 2016 Rice University
 *
 *  Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 *  the License. You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
 *  on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for
 *  the specific language governing permissions and limitations under the License.
 */
part of vellum.views;

/**
 * A [JavaScriptFileEditorView] that is rendered in a single containing HTML element in the browser.
 */
class JavaScriptFileEditorElementView extends JavaScriptFileEditorView
{
  /**
   * The HTML element that houses the editor.
   */
  Element _editorElement;

  /**
   * The CSS style that should be applied to the editor element when it is shown.
   */
  String _showDisplayCssStyle;

  /**
   * A unique identifier for the editor instance.
   */
  Object _editorId;

  @override
  Object get id => _editorId;

  /**
   * Constructs an editor reflecting the given view model rendered into the given HTML element.
   */
  JavaScriptFileEditorElementView(FileEditorViewModel vm, Element editorElement) : super(vm)
  {
    _editorElement = editorElement;

    // default _showDisplayCssStyle to the current element display style, or assume "inline" if not currently
    // visible.
    _showDisplayCssStyle = editorElement.style.display == "none" ? "inline" : editorElement.style.display;

    String languageMode = _vm.contentMode(
        (JavaLanguageContent java) => "java",
        (CLanguageContent c) => "c",
        (JavaScriptLanguageContent js) => "javascript");

    _editorId = createEditorPane(_editorElement.id, languageMode);
  }

  @override
  void show()
  {
    super.show();
    _editorElement.style.display = _showDisplayCssStyle;
  }

  @override
  void hide()
  {
    _editorElement.style.display = "none";
  }


}

/**
 * Create an editor pane rendered in the HTML element with id [elementId]. If the editor pane supports content
 * specific features, configure the editor to support content type [contentType].
 *
 * The following string values should be used for [contentType]:
 *
 * Content Type             String value
 * =================================
 * Java source code         "java"
 * C source code            "c"
 * JavaScript source code   "javascript"
 *
 */
@JS("")
external Object createEditorPane(String elementId, String contentType);